@@ -74,8 +74,8 @@ const WorkflowsList = ({ className }: IWorkflowsList): JSX.Element => {
 // -----------------------------------------------------------------------------
 const StyledWorkflowsList = styled(WorkflowsList)`
   && {
-    max-width: calc(1024px + 30px);
-    padding: 0 15px 15px 15px;
+    max-width: 1024px;
+    padding: 0 0 15px 0;
     margin: 0 auto;
     box-sizing: border-box;
   }
